<?php
/**
 * digicrew functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package digicrew
 */
require get_template_directory() . '/upgrade-to-pro/class-customize.php';
if ( ! function_exists( 'digicrew_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function digicrew_setup() {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on Theme Palace, use a find and replace
         * to change 'digicrew' to the name of your theme in all the template files.
         */
        load_theme_textdomain( 'digicrew' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );
        
        /* Woocommerce Plugin Support in Theme */
        add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
	    add_theme_support( 'wc-product-gallery-lightbox' );
	    add_theme_support( 'wc-product-gallery-slider' );	

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(
            array(
                'primary' => esc_html__( 'Primary', 'digicrew' ),
            )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'style',
                'script',
            )
        );

        // Set up the WordPress core custom background feature.

        $args = array(
                    'default-color' => 'ffffff',
                    'default-image' => '',
                );
        
        add_theme_support( 'custom-background', $args);

        /* Gutenberg */
        add_theme_support('wp-block-styles');
        add_theme_support('align-wide');
        // Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );

        /* Add editor style. */
        add_theme_support('editor-styles');
        add_theme_support('dark-editor-style');

         /*
         * This theme styles the visual editor to resemble the theme style,
         * specifically font, colors, icons, and column width.
        */
        add_editor_style('/assets/css/editor-style.css');

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height'      => 250,
                'width'       => 250,
                'flex-width'  => true,
                'flex-height' => true,
            )
        );
    }
endif;
add_action( 'after_setup_theme', 'digicrew_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $digicrew_content_width
 */
function digicrew_content_width() {
    $GLOBALS['content_width'] = apply_filters( 'digicrew_content_width', 640 );
}
add_action( 'after_setup_theme', 'digicrew_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function digicrew_widgets_init() {
    register_sidebar(
        array(
            'name'          => esc_html__( 'Sidebar', 'digicrew' ),
            'id'            => 'sidebar',
            'description'   => esc_html__( 'Add widgets here.', 'digicrew' ),
            'before_widget' => '<div id="%1$s" class="widget sidebar-box %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="title">',
            'after_title'   => '</h3>',
        )
    );
    register_sidebar(
        array(
            'name'          => esc_html__('Footer Widget Area', 'digicrew'),
            'id'            => 'footer-widget-area',
            'description'   => esc_html__('footer widget area', 'digicrew'),
            'before_widget' => '<div class="col-md-3 col-sm-6"><div id="%1$s" class="%2$s widget footer-box">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h3>',
            'after_title'   => '</h3>',
        )
    );
}
add_action( 'widgets_init', 'digicrew_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function digicrew_scripts() {

    wp_enqueue_style('bootstrap', get_template_directory_uri() .'/assets/css/bootstrap.css');
    wp_enqueue_style('animate', get_template_directory_uri() .'/assets/css/animate.css');
    wp_enqueue_style('fontawesome6.4.0', get_template_directory_uri() .'/assets/fontawesome6.5.1/css/all.min.css');

    wp_enqueue_style( 'slicknav',   get_template_directory_uri() . '/assets/css/slicknav.css' );
    wp_enqueue_style( 'digicrew-woocommerce', get_template_directory_uri() .'/assets/css/woocommerce.css');
    wp_enqueue_style('digicrew-responsive', get_template_directory_uri() .'/assets/css/responsive.css');
    wp_enqueue_style( 'digicrew-style', get_stylesheet_uri());
	
	
	
		/* Web Fonts Typography Settings code start */		

        wp_enqueue_style('digicrew-google-fonts',esc_url(digicrew_scripts2()));
		
		$font_var          = '300,400,600,700,900,300italic,400italic,600italic,700italic,900italic';
        $http              = ( ! empty( $_SERVER['HTTPS'] ) ) ? "https" : "http";
        $main_heading_font = str_replace( ' ' , '+', get_theme_mod( 'main_heading_font', 'Open Sans' ) );
        $menu_font         = str_replace( ' ' , '+', get_theme_mod( 'menu_font', 'Open Sans' ) );
        $theme_title       = str_replace( ' ' , '+', get_theme_mod( 'theme_title', 'Open Sans' ) );
        $desc_font_all     = str_replace( ' ' , '+', get_theme_mod( 'desc_font_all', 'Open Sans' ) );

        wp_enqueue_style('main_heading_font', $http . '://fonts.googleapis.com/css?family=' . $main_heading_font . ':' . $font_var);	
        wp_enqueue_style('menu_font', $http . '://fonts.googleapis.com/css?family=' . $menu_font . ':' . $font_var);	
        wp_enqueue_style('theme_title', $http . '://fonts.googleapis.com/css?family=' . $theme_title . ':' . $font_var);
        wp_enqueue_style('desc_font_all', $http . '://fonts.googleapis.com/css?family=' . $desc_font_all . ':' . $font_var);
	
	
	
    
    wp_enqueue_script( 'bootstrap',        get_template_directory_uri() . '/assets/js/bootstrap.js', array( 'jquery' ), true, true); 
    wp_enqueue_script( 'jquery-slicknav',  get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array( 'jquery' ), true, true); 
    wp_enqueue_script( 'slick',            get_template_directory_uri() . '/assets/js/slick.js', array( 'jquery' ), true, true);
    wp_enqueue_script( 'digicrew-custom',  get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ), true, true);

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
	
}
	
add_action( 'wp_enqueue_scripts', 'digicrew_scripts' );



/* Add Typography Settings code start */	
add_action('wp_enqueue_scripts', 'digicrew_custom_css');
function digicrew_custom_css()
{
    $output = '';
	
	$output .= '.site-title, .logo p, .site-description {
		font-family: ' . get_theme_mod('main_heading_font', 'Open Sans') . '!important;
		}
		nav.navbar.navbar-expand-lg.navbar-light li a,  .navbar-nav, .menu-item, .sub-menu > li > a{
			font-family: ' . get_theme_mod('menu_font', 'Open Sans') . '!important ;
		}
		.inner-banner-info h2, .wp-block-search, .wp-block-search__label,  h1, h2, h3, h4, h5, h6 {
			font-family: ' . get_theme_mod('theme_title', 'Open Sans') . ';
		}
       .comment-form textarea, .form-control, .comment-form .btn, .wp-block-search__button, .main-title-two, .sub-title, .btn-1, btn-1:hover, .btn-1:focus,
		a.lfour, html, body, div, span, applet, object, iframe, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, font, img, ins, kbd, q, s, samp, small, strike,  sub, sup, tt, var, b, u, i, center, dl, dt, dd, li, fieldset, form, label, legend, table, caption, tbody, tfoot, thead, tr, th, td, span, a, a:hover, a:focus 
		
		{
			font-family: ' . get_theme_mod('desc_font_all', 'Open Sans') . ';
		}';

    
    $output     .='
    .logo img{
        height:'.esc_attr(get_theme_mod('logo_height','100')).'px;
        width:'.esc_attr(get_theme_mod('logo_width','100')).'px;
    }';
    //custom css
    $custom_css = get_theme_mod('custom_css') ; 
    if (!empty ($custom_css)) {
        $output .= get_theme_mod('custom_css') . "\n";
    }

    wp_register_style('custom-header-style', false);
    wp_enqueue_style('custom-header-style', get_template_directory_uri() . '/css/custom-header-style.css');
    wp_add_inline_style('custom-header-style', $output);
}
/* Add Typography Settings code end */





function digicrew_scripts2() {
	// Include google webfont locally Typography Settings //
	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );
	
	$font_families = array(
		'Hind+Siliguri:wght@300;400;500;600;700',
		'Work+Sans:wght@300;400;500;600;700'
		
	);

	$fonts_url = add_query_arg( array(
		'family' => implode( '&family=', $font_families ),
		'display' => 'swap',
		'subset' => 'latin,latin-ext',
	), 'https://fonts.googleapis.com/css2' );
	
	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
	

	// Load the webfont.
	wp_enqueue_style(
		'Work Sans',
		$contents,
		array(),
		'1.0'
);}

/* Web Fonts Typography Settings code end */










if ( is_admin() ) {
	require_once('core/admin/admin-themes.php');
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';
 
 //Meta box display callback.

 // @param WP_Post $post Current post object.

function digicrew_add_sidebar_layout_box(){
    $post_id   = isset( $_GET['post'] ) ? $_GET['post'] : '';
    $template  = get_post_meta( $post_id, '_wp_page_template', true );
    $templates = array( 'templates/blossom-portfolio.php' ); //@todo change the template accordingly if it's a raratheme's theme.
    
    //for post
    add_meta_box( 
        'digicrew_sidebar_layout',
        __( 'Sidebar Layout', 'digicrew' ),
        'digicrew_sidebar_layout_callback', 
        'post',
        'normal',
        'high'
    );

    if( ! in_array( $template, $templates ) ){
        add_meta_box( 
            'digicrew_sidebar_layout',
            __( 'Sidebar Layout', 'digicrew' ),
            'digicrew_sidebar_layout_callback', 
            'page',
            'normal',
            'high'
        );
    }
}
add_action( 'add_meta_boxes', 'digicrew_add_sidebar_layout_box' );

$digicrew_sidebar_layout = array(    

    'no-sidebar'     => array(
         'value'     => 'no-sidebar',
         'label'     => __( 'Full Width', 'digicrew' ),
         'thumbnail' => esc_url( get_template_directory_uri() . '/images/full-width.png' )
    ),
   
    'left-sidebar' => array(
         'value'     => 'left-sidebar',
         'label'     => __( 'Left Sidebar', 'digicrew' ),
         'thumbnail' => esc_url( get_template_directory_uri() . '/images/left-sidebar.png' )         
    ),
    'right-sidebar' => array(
         'value'     => 'right-sidebar',
         'label'     => __( 'Right Sidebar', 'digicrew' ),
         'thumbnail' => esc_url( get_template_directory_uri() . '/images/right-sidebar.png' )         
    )    
    
);
function digicrew_sidebar_layout_callback(){
    global $post , $digicrew_sidebar_layout;
    wp_nonce_field( basename( __FILE__ ), 'digicrew_nonce' ); ?> 
    <table class="form-table">
        <tr>
            <td colspan="4"><em class="f13"><?php esc_html_e( 'Choose Sidebar Template', 'digicrew' ); ?></em></td>
        </tr>
        <tr>
            <td>
                <?php  
                    foreach( $digicrew_sidebar_layout as $field ){  
                        $layout = get_post_meta( $post->ID, '_digicrew_sidebar_layout', true ); ?>
                        <div class="hide-radio radio-image-wrapper" style="float:left; margin-right:30px;">
                            <input id="<?php echo esc_attr( $field['value'] ); ?>" type="radio" name="digicrew_sidebar_layout" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $layout ); if( empty( $layout ) ){ checked( $field['value'], 'default-sidebar' ); }?>/>
                            <label class="description" for="<?php echo esc_attr( $field['value'] ); ?>">
                                <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" alt="<?php echo esc_attr( $field['label'] ); ?>" />
                            </label>
                        </div>
                        <?php 
                    } // end foreach 
                ?>
                <div class="clear"></div>
            </td>
        </tr>
    </table> 
<?php 
}


function digicrew_save_sidebar_layout( $post_id ){
    global $digicrew_sidebar_layout;

    // Verify the nonce before proceeding.
    if( !isset( $_POST[ 'digicrew_nonce' ] ) || !wp_verify_nonce( $_POST[ 'digicrew_nonce' ], basename( __FILE__ ) ) )
        return;
    
    // Stop WP from clearing custom fields on autosave
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )  
        return;

    if( 'page' == $_POST['post_type'] ){  
        if( ! current_user_can( 'edit_page', $post_id ) ) return $post_id;  
    }elseif( ! current_user_can( 'edit_post', $post_id ) ){  
        return $post_id;  
    }

    $layout = isset( $_POST['digicrew_sidebar_layout'] ) ? sanitize_key( $_POST['digicrew_sidebar_layout'] ) : 'default-sidebar';

    if( array_key_exists( $layout, $digicrew_sidebar_layout ) ){
        update_post_meta( $post_id, '_digicrew_sidebar_layout', $layout );
    }else{
        delete_post_meta( $post_id, '_digicrew_sidebar_layout' );
    }
}
add_action( 'save_post' , 'digicrew_save_sidebar_layout' );




 
//Save meta box content.

// @param int $post_id Post ID
 
function DigiCrew_Wp_Blog_Post_Sidebar_Type_Save_Value_Function( $post_id ) {
    // Save logic goes here. Don't forget to include nonce checks!

   global $post;
 
    if(isset($_POST["project_font_icon"])):
         
        update_post_meta($post->ID, 'Project_Select_Option_Font_Icon_Meta_Key_Value', $_POST["project_font_icon"]);
     
    endif;
} 
add_action( 'save_post', 'DigiCrew_Wp_Blog_Post_Sidebar_Type_Save_Value_Function' );  
?>